==> flutter_snow_blower-0.0.1.tar.gz: lib/src/modules/start/create/mvc_modular/create_pages_files.dart <==
part of './create_mvc_modular.dart';

Future<void> _createPagesFiles(String package, bool complete) async {
  await Generate.module('modules/home', true, false);
  if (complete) {
    createStaticFile(
      libPath('modules/splash/splash_page.dart'),
      templates.splashPageModular(package),
    );

    // ** login
    createStaticFile(
      libPath('modules/login/login_module.dart'),
      templates.loginModule(),
    );
    createStaticFile(
      libPath('modules/login/pages/login/login_page.dart'),
      templates.loginPage(package, Architecture.mvcModular),
    );
    createStaticFile(
      libPath('modules/login/pages/login/login_controller.dart'),
      templates.loginControllerModular(package),
    );

    // i18n
    createStaticFile(
      libPath('i18n/login_i18n.dart'),
      templates.loginI18n(),
    );

    // widget
    createStaticFile(
      libPath('shared/widgets/email_text_field/email_text_field_widget.dart'),
      templates.emailTextFieldWidget(),
    );
    createStaticFile(
      libPath(
          'shared/widgets/password_text_field/password_text_field_widget.dart'),
      templates.passwordTextFieldWidget(),
    );

    // ** register
    createStaticFile(
      libPath('modules/login/pages/register/register_page.dart'),
      templates.registerPage(package, Architecture.mvcModular),
    );
    createStaticFile(
      libPath('modules/login/pages/register/register_controller.dart'),
      templates.registerControllerModular(package),
    );
  }
}

==> flutter_snow_blower-0.1.1.tar.gz: lib/src/modules/start/create/mvc_modular/create_pages_files.dart <==
part of './create_mvc_modular.dart';

Future<void> _createPagesFiles(String package, bool complete) async {
  await Generate.module('modules/home', true, false);
  
  createStaticFile(
    libPath('i18n/validators_i18n.dart'),
    templates.validatorsI18n(),
  );
  
  if (complete) {
    createStaticFile(
      libPath('modules/splash/splash_page.dart'),
      templates.splashPageModular(package),
    );

    // ** login
    createStaticFile(
      libPath('modules/login/login_module.dart'),
      templates.loginModule(),
    );
    createStaticFile(
      libPath('modules/login/pages/login/login_page.dart'),
      templates.loginPage(package, Architecture.mvcModular),
    );
    createStaticFile(
      libPath('modules/login/pages/login/login_controller.dart'),
      templates.loginControllerModular(package),
    );

    // i18n
    createStaticFile(
      libPath('i18n/login_i18n.dart'),
      templates.loginI18n(),
    );

    // widget
    createStaticFile(
      libPath('shared/widgets/email_text_field/email_text_field_widget.dart'),
      templates.emailTextFieldWidget(package, "src", Architecture.mvcModular),
    );
    createStaticFile(
      libPath(
          'shared/widgets/password_text_field/password_text_field_widget.dart'),
      templates.passwordTextFieldWidget(
          package, "src", Architecture.mvcModular),
    );

    // ** register
    createStaticFile(
      libPath('modules/login/pages/register/register_page.dart'),
      templates.registerPage(package, Architecture.mvcModular),
    );
    createStaticFile(
      libPath('modules/login/pages/register/register_controller.dart'),
      templates.registerControllerModular(package),
    );
  }
}
